Formasaurus
===========

.. image:: https://img.shields.io/pypi/v/Formasaurus.svg
   :target: https://pypi.python.org/pypi/Formasaurus
   :alt: PyPI Version

.. image:: https://img.shields.io/travis/TeamHG-Memex/Formasaurus/master.svg
   :target: http://travis-ci.org/TeamHG-Memex/Formasaurus
   :alt: Build Status

.. image:: http://codecov.io/github/TeamHG-Memex/Formasaurus/coverage.svg?branch=master
   :target: http://codecov.io/github/TeamHG-Memex/Formasaurus?branch=master
   :alt: Code Coverage

.. image:: https://readthedocs.org/projects/formasaurus/badge/?version=latest
   :target: http://formasaurus.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation

Formasaurus is a Python package that tells you the type of an HTML form
and its fields using machine learning.

It can detect if a form is a login, search, registration, password recovery,
"join mailing list", contact, order form or something else, which field
is a password field and which is a search query, etc.

License is MIT.

.. toctree::
   :maxdepth: 2

   install
   usage
   howitworks
   api
   contributing
   changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

